# pinenut
A machine learning framework, which developed by Neil Jiang.
It supports define-by-run computational graph and automatically calculate the gradients of functions.
It supports GPU acceleration.
It is powerful, flexible and easy to understand.
